<?php defined('SYSPATH') or die('No direct script access.');

class Controller_Teacher_Map extends Controller_UserEnvi {
    
    public function action_show()
    {
        $twig = Twig::factory('teacher/map/show');
        $id = $this->request->param('id');
        $db = new Model_Teacher_Map;
        $map = $db->getMapForDiscipline($this->UserInfo['TeacherID'], $id);
        
        if($map->count() == 0)
            throw HTTP_Exception::factory(404, "Учебная карта дисциплины с ID $id не найдена!");
        
        $twig->User = $this->UserInfo;
        $twig->Map = $this->getMapInfo($map);
        $twig->Subject = $this->getSubjectInfo($db, $id);
        $this->response->body($twig);
    }
    
    public function action_create()
    {
        $twig = Twig::factory('teacher/map/create');
        $twig->User = $this->UserInfo;
        
        $this->response->body($twig);
    }
    
    public function action_edit()
    {
		$twig = Twig::factory('teacher/map/edit');
        $id = $this->request->param('id');
        $db = new Model_Teacher_Map;
        $map = $db->getMapForDiscipline($this->UserInfo['TeacherID'], $id);
		
		$twig->User = $this->UserInfo;
		$twig->Map = $this->getMapInfo($map);
		$twig->Discipline = $this->getSubjectInfo($db, $id);
		$twig->SubjectsList = array(
			1 => array(
				'ID' => '1',
				'Title' =>'Математический анализ'
			),
			2 => array(
				'ID' => '2',
				'Title' =>'Дифференциальные уравнения'
			),
			3 => array(
				'ID' => '3',
				'Title' =>'Операционные системы'
			),
			4 => array(
				'ID' => '4',
				'Title' =>'Топология'
			)
		);
		$twig->GradesList = array(
			1 => array(
				'ID' => '1',
				'Title' =>'Курс 1'
			),
			2 => array(
				'ID' => '2',
				'Title' =>'Курс 2'
			),
			3 => array(
				'ID' => '3',
				'Title' =>'Курс 3'
			),
			4 => array(
				'ID' => '4',
				'Title' =>'Курс 4'
			),
			5 => array(
				'ID' => '5',
				'Title' =>'Курс 6'
			),
			6 => array(
				'ID' => '6',
				'Title' =>'Магистратура 1'
			),
			7=> array(
				'ID' => '7',
				'Title' =>'Магистратура 2'
			)
		);
			
		$this->response->body($twig);
    }
	
    private function getMapInfo($map) {
        $mapHandled = array();
        
        $maxRate = 0; $i = 0; $module = 0;
        foreach($map as $row)
        {
            if($row['ModuleID'] != $module)
            {
                $i++;
                $module = $row['ModuleID'];
				$mapHandled[$i]['ModuleID'] = $row['ModuleID'];
				$mapHandled[$i]['CurrentControl'] = 0;
				$mapHandled[$i]['LandmarkControl'] = 0;
            }
            if(!isset($mapHandled[$i]['SubmodulesCount']))
            {
                $mapHandled[$i]['SubmodulesCount'] = 0;
                $mapHandled[$i]['MaxRate'] = 0;
            }
            $j = $mapHandled[$i]['SubmodulesCount'] += 1;
            $mapHandled[$i]['MaxRate'] += (int) $row['MaxRate'];
            $mapHandled[$i]['ModuleTitle'] = $row['ModuleName'];
			$mapHandled[$i][$j]['SubmoduleID'] = $row['SubmoduleID'];
            $mapHandled[$i][$j]['Title'] = $row['SubModuleName'];
            $mapHandled[$i][$j]['Description'] = $row['SubmoduleDescription'];
			$mapHandled[$i][$j]['SubmoduleControl'] = $row['SubmoduleControl'];
            $mapHandled[$i][$j]['MaxRate'] = (int) $row['MaxRate'];
            $maxRate += $row['MaxRate'];
			if ($row['SubmoduleControl'] == 'CurrentControl')
				 $mapHandled[$i]['CurrentControl'] += (int) $row['MaxRate'];
			if ($row['SubmoduleControl'] == 'LandmarkControl')
				 $mapHandled[$i]['LandmarkControl'] += (int) $row['MaxRate'];
        }
		$mapHandled['ModulesCount'] = $i;
		$mapHandled['MaxRate'] = (int) $maxRate; 

        return $mapHandled;
    }
    
    public function getSubjectInfo($db, $id)
    {
        $info = $db->getDisciplineInfoByID($id);
        
        if($info->count() == 0)
           throw HTTP_Exception::factory(404, "Учебная карта дисциплины с ID $id не найдена!");
		else
			$info = $info->offsetGet(0);
		
		$teachers = $db->getTeachersForDiscipline($id);
		
        $subject['SubjectName'] = $info['SubjectName'];
		$subject['SubjectID'] = $info['SubjectID'];
        //if($info['ExamType'] == 'exam')
        //{
        //    $subject['Control'] = 'Экзамен';
        //}
        //elseif($info['ExamType'] == 'credit')
        //{
        //    $subject['Control'] = 'Зачет';
        //}
		$subject['ExamType'] = $info['ExamType'];
        
        $subject['LectureHours'] = $info['LectionCount'];
        $subject['PracticeHours'] = $info['PracticeCount'];
		$subject['GradeID'] = $info['DisciplineGrade'];
        
        $teachersHandled = array(); $i = 0;
        
        foreach ($teachers as $row) {
            $teachersHandled[$i] = $row['LastName'].' '.$row['FirstName'].'';
            if(!empty($row['TeacherSecond']))
            {
                $teachersHandled[$i] .= ' '.$row['SecondName'];
            }
            $i++;
        }
        $subject['Teachers'] = implode(', ', $teachersHandled);
		
		return $subject;
    }
}
            